@@ -4,6 +4,8 @@ import subprocess
 
 import semver
 import typer
+from plumbum import FG, ProcessExecutionError
+from plumbum import local as lr
 
 app = typer.Typer()
 
@@ -11,10 +13,15 @@ app = typer.Typer()
 def git(*args, output=True):
     r = subprocess.check_output(["git"] + list(args))
     if output:
+        print(args)  # noqa
         print(r)  # noqa
     return r
 
 
+def git_num_changes():
+    return len(git("status", "--porcelain").splitlines())
+
+
 def get_version():
     return git("describe", "--tags").decode().strip()
 
@@ -47,3 +54,18 @@ def bump_version():
 
     print(f"bump from {v} to {n}")  # noqa
     git("tag", n)
+
+
+@app.command()
+def local():
+    has_changes = git_num_changes() > 0
+    try:
+        if has_changes:
+            git("add", ".")
+            git("commit", "-m", "local debug commit")
+        lr["gitlab-runner"]["exec", "docker", "build"] & FG
+    except ProcessExecutionError:
+        exit(1)
+    finally:
+        if has_changes:
+            git("reset", "HEAD~1")
